@@ -19,8 +19,10 @@
 __all__ = [
     'EnvironmentVariableFixture',
     'MonkeyPatch',
+    'PackagePathEntry',
     'PopenFixture',
     'PythonPackage',
+    'PythonPathEntry',
     'TempDir',
     ]
 
@@ -28,5 +30,7 @@ __all__ = [
 from fixtures._fixtures.environ import EnvironmentVariableFixture
 from fixtures._fixtures.monkeypatch import MonkeyPatch
 from fixtures._fixtures.popen import PopenFixture
+from fixtures._fixtures.packagepath import PackagePathEntry
 from fixtures._fixtures.pythonpackage import PythonPackage
+from fixtures._fixtures.pythonpath import PythonPathEntry
 from fixtures._fixtures.tempdir import TempDir
