@@ -17,8 +17,10 @@ def load_tests(loader, standard_tests, pattern):
     test_modules = [
         'environ',
         'monkeypatch',
+        'packagepath',
         'popen',
         'pythonpackage',
+        'pythonpath',
         'tempdir',
         ]
     prefix = "fixtures.tests._fixtures.test_"
